'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const vscode_1 = require("vscode");
const vscode_languageclient_1 = require("vscode-languageclient");
const path = require("path");
var OpenDocNotification;
(function (OpenDocNotification) {
    OpenDocNotification.type = new vscode_languageclient_1.NotificationType('stylable/openDocumentNotification');
})(OpenDocNotification || (OpenDocNotification = {}));
/**
 * vs-code plugin API implementation
 * this is the main entry point for the vs studio code extension API
 * see https://code.visualstudio.com/docs/extensionAPI/activation-events
 */
function activate(context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let serverModule = require.resolve('./lib/server.js'); //context.asAbsolutePath(path.join('dist', 'src', 'server', 'server.js'));
        let debugOptions = { execArgv: [''] };
        // let debugOptions = {execArgv: ['--inspect']}; // Turn on debugging messages in output
        let serverOptions = {
            run: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc },
            debug: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc, options: debugOptions, runtime: 'node' }
        };
        let clientOptions = {
            documentSelector: [{ language: 'stylable' }, { language: 'typescript' }, { language: 'javascript' },],
            diagnosticCollectionName: 'stylable',
        };
        const client = new vscode_languageclient_1.LanguageClient('stylable', serverOptions, clientOptions);
        // client.trace = Trace.Verbose; // Elevate debugging message info in output
        context.subscriptions.push(client.start());
        yield client.onReady();
        const files = yield vscode_1.workspace.findFiles('**/*.st.css');
        yield Promise.all(files.map((file) => vscode_1.workspace.openTextDocument(file.fsPath)));
        client.onNotification(OpenDocNotification.type, (uri) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const doc = yield vscode_1.workspace.openTextDocument(vscode_1.Uri.parse(uri));
            if (doc.fileName.endsWith('.js')) {
                const uris = yield vscode_1.workspace.findFiles('**/' + path.basename(doc.fileName).slice(0, -3) + '.d.ts');
                uris.forEach(u => {
                    vscode_1.workspace.openTextDocument(u);
                });
            }
        }));
        return client;
    });
}
exports.activate = activate;
/**
 * vs-code plugin API implementation
 * deactivation cleanup
 */
function deactivate() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
    });
}
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map